@@ -226,7 +226,21 @@ class CommonIRCConnection(IRCConnection):
         self._generic_target("NOTICE", target, message, split_lines)
 
     def join(self, channels):
-        self.send("JOIN %s" % (",".join(channels),))
+        """If called with an object that has a ``get'' method, uses the get
+        method to get passwords for *all* channels, otherwise sends a JOIN
+        for channels without passwords. It is therefore impossible to join
+        a mixture of channels with and without password with one call to
+        this method.
+        """
+
+        if hasattr(channels, "get"):
+            chans = []
+            for channel in channels:
+                chans.append(channel)
+                passws.append(channels.get(channel))
+            self.send("JOIN %s %s" % (",".join(chans), ",".join(passws)))
+        else:
+            self.send("JOIN %s" % (",".join(channels),))
 
     def nick(self, new_nickname):
         self.send("NICK :%s" % (nickname,))
